function [acc_per_k] = eval_horizon(sys, data, K, start_size)
   % EVAL HORIZON: Generate precision curve w.r.t prediction dept 
   % 
   %  acc_per_k = EVAL_HORIZON_POLY(SYS, DATASET, K)
   %  The function take the dataset (iddata obj) with multiple experiments and deal with the identified model (SYS) in order
   %  to produce an accuracy per prediction depth from 1 to K. This function is designed to use a inherit object from ModelAstract class.
   %
   %  

    % Check sys type  
    valid_type = isa(sys, 'ModelAbstract');
    if  not(valid_type)
       throw(MException('conv_k_step_predict.badtype',"Bad sys type. Excepted idpoly"));
    end
    

    % Check data type
    valid_type = isa(data, 'iddata');
    if  not(valid_type)
       throw(MException('conv_k_step_predict.badtype',"Bad data type. Excepted iddata"));
    end


    if not (data.Domain == "Time")
       throw(MException('conv_k_step_predict.badDomain',"Only Time Domain is supported ! "));
    end


    % Check K type
    valid_type = isa(K, 'double');
    if  not(valid_type)
       throw(MException('conv_k_step_predict.badtype',"Bad K type. Excepted double"));
    end



    function [y_pred_mat, y_real_mat] = intern_eval_horizon(sys, data, K, start_size)

        % Check the largest polynome.
        input_size = start_size;
        data_size = size(data, 1);
        output_size = size(data.y, 2);

        % Number of prediction to do
        nb_steps = int32((data_size-input_size-K-1));
        disp(nb_steps);

        % Create the output matrix based on the model and data
        y_pred_mat = zeros([nb_steps, K, output_size]);
        y_real_mat = zeros([nb_steps, K, output_size]);


        for k =   0 : 1  : nb_steps
            OFFSET = k;
            z_local = iddata(data.y(OFFSET+1:OFFSET+K+input_size+1,:),data.u(OFFSET+1:1+OFFSET+K+input_size,:), data.Ts);
            past_data = z_local(1:input_size);
            future_inputs = iddata([],z_local.u(input_size+1:input_size+K,:), data.Ts);

            yf = sys.forecast(past_data,future_inputs);

            y_real_mat(1+k ,:,:) = data.y(input_size+OFFSET+1:OFFSET+K+input_size,:);
            y_pred_mat(1+k ,:,:) = yf.y;

        end
    end
        

    output_size = size(getexp(data, data.ExperimentName{1}).y,2);
    [y_real_mat, y_pred_mat] = intern_eval_horizon(sys, getexp(data, data.ExperimentName{1}), K, start_size);

    for idx = 2:length(data.ExperimentName)
        [y_real_mat_batch, y_pred_mat_batch] = intern_eval_horizon(sys, getexp(data, data.ExperimentName{idx}), K, start_size);
        y_real_mat = [y_real_mat; y_real_mat_batch];
        y_pred_mat = [y_pred_mat; y_pred_mat_batch];
    end
    
    residual = y_real_mat-y_pred_mat;
    acc_per_k = sqrt(sum(residual(:,:,1).^2+residual(:,:,2).^2,1)/size(y_real_mat,1));

end