function [y_pred_mat, y_real_mat] = predict_horizon_idpoly(sys, data, K)

    % Check sys type  
    valid_type = isa(sys, 'idpoly');
    if  not(valid_type)
       throw(MException('conv_k_step_predict.badtype',"Bad sys type. Excepted idpoly"));
    end
    
    % Check data type
    valid_type = isa(data, 'iddata');
    if  not(valid_type)
       throw(MException('sys.badtype',"The sys obj must be a iddata object."));
    end
    
    % Check data domain
    if not (data.Domain == "Time")
       throw(MException('data.badDomain',"Only Time Domain is supported ! "));
    end
    
    
    % Check K type
    valid_type = isa(K, 'double');
    if  not(valid_type)
       throw(MException('K.badtype',"Bad K type. Excepted double"));
    end
    
    
    % Check the largest polynome.
    input_size = 1+1+2+max([size(sys.A, 2), size(sys.B, 2), size(sys.F, 2), size(sys.C, 2), size(sys.D, 2)]);
    data_size = size(data, 1);
    output_size = size(data.y, 2);
    
    % Number of prediction to do
    nb_steps = int32((data_size-input_size)/K);
    disp(nb_steps);
    
    % Create the output matrix based on the model and data
    y_pred_mat = zeros([nb_steps*K, size(data.y,2)]);
    y_real_mat = zeros([nb_steps*K, size(data.y,2)]);
    
    for k =   0 : 1  : nb_steps-2
        OFFSET = k*K;
        z_local = iddata(data.y(OFFSET+1:OFFSET+K+input_size+1),data.u(OFFSET+1:1+OFFSET+K+input_size,:), "Ts", data.Ts);
        past_data = z_local(1:input_size);
        future_inputs = iddata([],z_local.u(input_size+1:input_size+K,:), "Ts", data.Ts);
    
        yf = forecast(sys,past_data,K,future_inputs);
    
        y_real_mat(1+k*K : k*K+K,:) = data.y(input_size+OFFSET+1:OFFSET+K+input_size,1);
        y_pred_mat(1+k*K : k*K+K,:) = yf.y;
    
    
    end
    
    end