function [y_pred_mat, y_real_mat] = predict_horizon_ss(sys, data, K, start_size)
   % PREDICT_HORIZON_POLY Function to perform severals forecasting for a given model. 
   % 
   % 
   %   [y_pred_mat, y_real_mat] = PREDICT_HORIZON_POLY(SYS, DATA, K, START_SIZE)
   %              This function perform severals prediction using the forecast function from the matlab identification toolsbox. 
   %              It allows you to have severals prediction side by side with prediction form different dept contrary to the function compare. 
   %              This function is designed to work with the idss object. It cannot deal with multiple experiment iddata object. 
   %              The START_SIZE argument is used to define the dept observation horizon for the matlab forecast method. 


    % Check sys type  
    valid_type = isa(sys, 'idss');
    if  not(valid_type)
       throw(MException('sys.badtype',"Bad sys type. Excepted idss system"));
    end
    
    % Check data type
    valid_type = isa(data, 'iddata');
    if  not(valid_type)
       throw(MException('data.badtype',"The sys obj must be a iddata object."));
    end
    
    % Check data domain
    if not (data.Domain == "Time")
       throw(MException('data.badDomain',"Only Time Domain is supported ! "));
    end
    
    
    % Check K type
    valid_type = isa(K, 'double');
    if  not(valid_type)
       throw(MException('K.badtype',"Bad K type. Excepted double"));
    end
    
    % Check the largest polynome.
    input_size =start_size;
    data_size = size(data, 1);
    
    % Number of prediction to do
    nb_steps = floor((data_size-input_size)/K)  ;
    disp(nb_steps);
    
    % Create the output matrix based on the model and data
    y_pred_mat = zeros([nb_steps*K, size(data.y,2)]);
    y_real_mat = zeros([nb_steps*K, size(data.y,2)]);
    
    for k =   0 : 1  : nb_steps-1
        OFFSET = k*K;
        z_local = iddata(data.y(OFFSET+1:OFFSET+K+input_size+1,:),data.u(OFFSET+1:1+OFFSET+K+input_size,:), data.Ts);
        past_data = z_local(1:input_size);
        future_inputs = iddata([],z_local.u(input_size+1:input_size+K,:));
    
        yf = forecast(sys,past_data,K,future_inputs);
        y_real_mat(1+k*K : k*K+K,:) = data.y(input_size+OFFSET+1:OFFSET+K+input_size,:);
        y_pred_mat(1+k*K : k*K+K,:) = yf.y;
    
    end
    
    end